/// <reference types="node" />
import * as anchor from "@project-serum/anchor";
import { Program, Provider } from "@project-serum/anchor";
import { AccountInfo as TokenAccountInfo } from "@solana/spl-token";
import { AccountInfo, PublicKey, Signer, TransactionInstruction } from "@solana/web3.js";
import { ICreateTokenBondingArgs, SplTokenBonding } from "@strata-foundation/spl-token-bonding";
import { BigInstructionResult, ICreateArweaveUrlArgs, InstructionResult, ITokenWithMeta, SplTokenMetadata, TypedAccountParser } from "@strata-foundation/spl-utils";
import { CollectiveV0, SplTokenCollectiveIDL, TokenRefV0 } from "./generated/spl-token-collective";
export * from "./generated/spl-token-collective";
export interface ITokenWithMetaAndAccount extends ITokenWithMeta {
    publicKey?: PublicKey;
    tokenRef?: ITokenRef;
    account?: TokenAccountInfo;
}
interface TokenAccount {
    pubkey: PublicKey;
    account: AccountInfo<Buffer>;
    info: TokenAccountInfo;
}
export interface ICreateCollectiveArgs {
    /** Payer for this transaction */
    payer?: PublicKey;
    /**
     * Token metadata that, if provided, will create metaplex spl-token-metadata for this collective.
     *
     * Reccommended to always fill this out so that your token displays with a name, symbol, and image.
     */
    metadata?: ICreateArweaveUrlArgs & {
        /** The metaplex file upload url to use. For devnet, needs to be uploadFile2, prod is uploadFileProd2 url. TODO: Once small file support is added, switch to uploadFile4 */
        uploadUrl?: string;
    };
    /**
     * If `mint` is not provided, create a bonding curve automatically for this collective.
     */
    bonding?: ICreateTokenBondingArgs;
    /** The mint to base this collective around. It is recommended for compatability that all collectives be on a bonding curve, so it's easy to make user interfaces that can buy in and out of your social tokens */
    mint?: PublicKey;
    /** **Default:** Fetch from mint. This may not be possible if the mint is being created in the same transaction as the collective. */
    mintAuthority?: PublicKey;
    /** The authority of this collective */
    authority?: PublicKey;
    /** The configs around what is and isn't allowed in the collective */
    config: ICollectiveConfig;
}
/** See [InitializeTokenBondingArgs](/docs/api/spl-token-bonding/interfaces/ICreateTokenBondingArgs) */
export interface ITokenBondingParams {
    /** The curve to create this social token on. **Default:** Curve from the collective's config */
    curve?: PublicKey;
    buyBaseRoyaltyPercentage: number;
    buyTargetRoyaltyPercentage: number;
    sellBaseRoyaltyPercentage: number;
    sellTargetRoyaltyPercentage: number;
    /** **Default:** uses decimals from collective config, or 9 */
    targetMintDecimals?: number;
    buyBaseRoyalties?: PublicKey;
    buyBaseRoyaltiesOwner?: PublicKey;
    buyTargetRoyalties?: PublicKey;
    buyTargetRoyaltiesOwner?: PublicKey;
    sellBaseRoyalties?: PublicKey;
    sellBaseRoyaltiesOwner?: PublicKey;
    sellTargetRoyalties?: PublicKey;
    sellTargetRoyaltiesOwner?: PublicKey;
}
export interface ICreateSocialTokenArgs {
    /**
     * Is this the primary social token for this wallet? **Default:** true
     *
     * A primary social token is the social token people should see when they look up your wallet. While it's possible to belong to many
     * collectives, generally most people will have one social token.
     */
    isPrimary?: boolean;
    /** If this social token already exists, don't throw an error. **Default:** false */
    ignoreIfExists?: boolean;
    /** The payer for this account and txn */
    payer?: PublicKey;
    /** The collective to create this social token under. **Default:**: the Open Collective*/
    collective?: PublicKey;
    /** The spl-name-service name to associate with this account. Will create an unclaimed social token. */
    name?: PublicKey;
    /** The spl-name-service name class associated with name above, if provided */
    nameClass?: PublicKey;
    /** The spl-name-service name paent associated with name above, if provided */
    nameParent?: PublicKey;
    /**
     * Token metadata that, if provided, will create metaplex spl-token-metadata for this collective.
     *
     * Reccommended to fill this out so that your token displays with a name, symbol, and image.
     */
    metadata: ICreateArweaveUrlArgs & {
        /**
         * Getting a uri for token metadata is a process that involves a separate transaction and an upload to arweave.
         *
         * To save time and effort, this will use the {@link ICollectiveConfig.unclaimedTokenMetadataSettings.uri}. While the name and symbol will not match properly, the name
         * and symbol on chain will be correct.
         *
         * **Default:** false
         */
        useCollectiveDefaultUri?: boolean;
        /**
         * The metaplex file upload url to use. For devnet, needs to be uploadFile2, prod is uploadFileProd2 url. TODO: Once small file support is added, switch to uploadFile4
         */
        uploadUrl?: string;
    };
    /** The wallet to create this social token under, defaults to `provider.wallet` */
    owner?: PublicKey;
    /**
     * **Default:** New generated keypair
     *
     * Pass in the keypair to use for the mint. Useful if you want a vanity keypair
     */
    targetMintKeypair?: anchor.web3.Keypair;
    /** Params for the bonding curve  */
    tokenBondingParams: ITokenBondingParams;
}
export interface IClaimSocialTokenArgs {
    /**
     * Is this the primary social token for this wallet? **Default:** true
     *
     * A primary social token is the social token people should see when they look up your wallet. While it's possible to belong to many
     * collectives, generally most people will have one social token.
     */
    isPrimary?: boolean;
    /** The payer for this txn */
    payer?: PublicKey;
    /** The owning wallet of this social token. **Default:**: `provider.wallet` */
    owner?: PublicKey;
    /** The token ref of the token we are claiming */
    tokenRef: PublicKey;
    /** Change the smart-contract level name for this token without changing the url. To do a full update to token metadata, directly use SplTokenMetadata after a claim */
    tokenName?: string;
    /** Change the smart-contract level symbol for this token without changing the url. To do a full update to token metadata, directly use SplTokenMetadata after a claim */
    symbol?: string;
    /** The buy base royalties destination. **Default:** ATA of owner */
    buyBaseRoyalties?: PublicKey;
    /** The buy target royalties destination. **Default:** ATA of owner */
    buyTargetRoyalties?: PublicKey;
    /** The sell base royalties destination. **Default:** ATA of owner */
    sellBaseRoyalties?: PublicKey;
    /** The sell target royalties destination. **Default:** ATA of owner */
    sellTargetRoyalties?: PublicKey;
    /**
     * Ignore missing name account. Useful if you're creating the name in the same txn.
     *
     * Otherwise, the sdk checks to make sure the name account exists before claiming to provide a more useful error
     *
     * **Default:** false
     */
    ignoreMissingName?: boolean;
}
interface ITokenRefKeyArgs {
    isPrimary?: boolean;
    owner?: PublicKey;
    name?: PublicKey;
    collective?: PublicKey;
}
export interface IRoyaltySetting {
    /**
     * In the case of an unclaimed token, is this royalty account required to be owned by the name account.
     *
     * If `true`, when the token is claimed, the owner of the name that's claiming it will receive all of the funds in the royalty account
     */
    ownedByName?: boolean;
    /**
     * A static address such that all curves must have this as the royalty address.
     */
    address?: number;
}
export interface ITokenBondingSettings {
    curve?: PublicKey;
    minSellBaseRoyaltyPercentage?: number;
    minSellTargetRoyaltyPercentage?: number;
    maxSellBaseRoyaltyPercentage?: number;
    maxSellTargetRoyaltyPercentage?: number;
    minBuyBaseRoyaltyPercentage?: number;
    minBuyTargetRoyaltyPercentage?: number;
    maxBuyBaseRoyaltyPercentage?: number;
    maxBuyTargetRoyaltyPercentage?: number;
    targetMintDecimals?: number;
    buyBaseRoyalties?: IRoyaltySetting;
    sellBaseRoyalties?: IRoyaltySetting;
    buyTargetRoyalties?: IRoyaltySetting;
    sellTargetRoyalties?: IRoyaltySetting;
    minPurchaseCap?: number;
    maxPurchaseCap?: number;
    minMintCap?: number;
    maxMintCap?: number;
}
export interface ITokenMetadataSettings {
    /** The default symbol for an unclaimed token */
    symbol?: string;
    /** The default uri for an unclaimed token */
    uri?: string;
    /** Enforce that the name of the unclaimed token matches the spl-name-service name */
    nameIsNameServiceName?: boolean;
}
export interface ICollectiveConfig {
    /**
     * A collective can either be open or closed. A closed collective must sign on the creation of _any_ social token
     * within the collective. An open collective allows any social tokens to bind themself to the collective token, so long
     * as they follow the CollectiveConfig settings
     */
    isOpen: boolean;
    /** Settings for bonding curves on unclaimed tokens */
    unclaimedTokenBondingSettings?: ITokenBondingSettings;
    /** Settings for bonding curves on claimed tokens */
    claimedTokenBondingSettings?: ITokenBondingSettings;
    /** Settings for token metadata of unclaimed tokens */
    unclaimedTokenMetadataSettings?: ITokenMetadataSettings;
}
/**
 * Unified tokenref interface wrapping the raw TokenRefV0
 */
export interface ITokenRef extends TokenRefV0 {
    publicKey: PublicKey;
}
/**
 * Unified collective interface wrapping the raw CollectiveV0
 */
export interface ICollective extends CollectiveV0 {
    publicKey: PublicKey;
}
export declare class SplTokenCollective {
    program: Program<SplTokenCollectiveIDL>;
    splTokenBondingProgram: SplTokenBonding;
    splTokenMetadata: SplTokenMetadata;
    provider: Provider;
    static ID: anchor.web3.PublicKey;
    static OPEN_COLLECTIVE_ID: anchor.web3.PublicKey;
    static OPEN_COLLECTIVE_BONDING_ID: anchor.web3.PublicKey;
    static OPEN_COLLECTIVE_MINT_ID: anchor.web3.PublicKey;
    static init(provider: Provider, splCollectiveProgramId?: PublicKey, splTokenBondingProgramId?: PublicKey): Promise<SplTokenCollective>;
    constructor(opts: {
        provider: Provider;
        program: Program<SplTokenCollectiveIDL>;
        splTokenBondingProgram: SplTokenBonding;
        splTokenMetadata: SplTokenMetadata;
    });
    get programId(): anchor.web3.PublicKey;
    get rpc(): anchor.RpcNamespace<SplTokenCollectiveIDL, {
        name: "initializeCollectiveV0";
        accounts: [{
            name: "collective";
            isMut: true;
            isSigner: false;
        }, {
            name: "mint";
            isMut: false;
            isSigner: false;
        }, {
            name: "mintAuthority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "InitializeCollectiveV0Args";
            };
        }];
    } | {
        name: "initializeOwnedSocialTokenV0";
        accounts: [{
            name: "initializeArgs";
            accounts: [{
                name: "payer";
                isMut: true;
                isSigner: true;
            }, {
                name: "collective";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenBonding";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenMetadata";
                isMut: false;
                isSigner: false;
            }, {
                name: "baseMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "targetMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "systemProgram";
                isMut: false;
                isSigner: false;
            }, {
                name: "rent";
                isMut: false;
                isSigner: false;
            }, {
                name: "clock";
                isMut: false;
                isSigner: false;
            }];
        }, {
            name: "authority";
            isMut: false;
            isSigner: false;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "tokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "owner";
            isMut: false;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "InitializeSocialTokenV0Args";
            };
        }];
    } | {
        name: "initializeUnclaimedSocialTokenV0";
        accounts: [{
            name: "initializeArgs";
            accounts: [{
                name: "payer";
                isMut: true;
                isSigner: true;
            }, {
                name: "collective";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenBonding";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenMetadata";
                isMut: false;
                isSigner: false;
            }, {
                name: "baseMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "targetMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "systemProgram";
                isMut: false;
                isSigner: false;
            }, {
                name: "rent";
                isMut: false;
                isSigner: false;
            }, {
                name: "clock";
                isMut: false;
                isSigner: false;
            }];
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "tokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMetadata";
            isMut: false;
            isSigner: false;
        }, {
            name: "name";
            isMut: false;
            isSigner: false;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "InitializeSocialTokenV0Args";
            };
        }];
    } | {
        name: "claimSocialTokenV0";
        accounts: [{
            name: "payer";
            isMut: false;
            isSigner: true;
        }, {
            name: "collective";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "newTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenBonding";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMetadata";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenBondingAuthority";
            isMut: false;
            isSigner: false;
        }, {
            name: "metadataUpdateAuthority";
            isMut: false;
            isSigner: false;
        }, {
            name: "name";
            isMut: false;
            isSigner: false;
        }, {
            name: "owner";
            isMut: true;
            isSigner: true;
        }, {
            name: "baseMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "targetMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "buyBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "buyTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "sellBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "sellTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newBuyBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newBuyTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newSellBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newSellTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "royaltiesOwner";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenBondingProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenMetadataProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "ClaimSocialTokenV0Args";
            };
        }];
    } | {
        name: "updateTokenBondingV0";
        accounts: [{
            name: "collective";
            isMut: false;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenBonding";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenBondingAuthority";
            isMut: false;
            isSigner: false;
        }, {
            name: "owner";
            isMut: false;
            isSigner: true;
        }, {
            name: "tokenBondingProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "baseMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "targetMint";
            isMut: false; /**
             * Run {@link claimSocialTokenInstructions}
             * @param args
             */
            isSigner: false;
        }, {
            name: "buyBaseRoyalties";
            isMut: false;
            isSigner: false;
        }, {
            name: "buyTargetRoyalties";
            isMut: false;
            isSigner: false;
        }, {
            name: "sellBaseRoyalties";
            isMut: false;
            isSigner: false;
        }, {
            name: "sellTargetRoyalties";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "UpdateTokenBondingV0ArgsWrapper";
            };
        }];
    }>;
    get instruction(): anchor.InstructionNamespace<SplTokenCollectiveIDL, {
        name: "initializeCollectiveV0";
        accounts: [{
            name: "collective";
            isMut: true;
            isSigner: false;
        }, {
            name: "mint";
            isMut: false;
            isSigner: false;
        }, {
            name: "mintAuthority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "InitializeCollectiveV0Args";
            };
        }];
    } | {
        name: "initializeOwnedSocialTokenV0";
        accounts: [{
            name: "initializeArgs";
            accounts: [{
                name: "payer";
                isMut: true;
                isSigner: true;
            }, {
                name: "collective";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenBonding";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenMetadata";
                isMut: false;
                isSigner: false;
            }, {
                name: "baseMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "targetMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "systemProgram";
                isMut: false;
                isSigner: false;
            }, {
                name: "rent";
                isMut: false;
                isSigner: false;
            }, {
                name: "clock";
                isMut: false;
                isSigner: false;
            }];
        }, {
            name: "authority";
            isMut: false;
            isSigner: false;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "tokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "owner";
            isMut: false;
            isSigner: true;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "InitializeSocialTokenV0Args";
            };
        }];
    } | {
        name: "initializeUnclaimedSocialTokenV0";
        accounts: [{
            name: "initializeArgs";
            accounts: [{
                name: "payer";
                isMut: true;
                isSigner: true;
            }, {
                name: "collective";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenBonding";
                isMut: false;
                isSigner: false;
            }, {
                name: "tokenMetadata";
                isMut: false;
                isSigner: false;
            }, {
                name: "baseMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "targetMint";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "buyTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellBaseRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "sellTargetRoyalties";
                isMut: false;
                isSigner: false;
            }, {
                name: "systemProgram";
                isMut: false;
                isSigner: false;
            }, {
                name: "rent";
                isMut: false;
                isSigner: false;
            }, {
                name: "clock";
                isMut: false;
                isSigner: false;
            }];
        }, {
            name: "authority";
            isMut: false;
            isSigner: true;
        }, {
            name: "payer";
            isMut: true;
            isSigner: true;
        }, {
            name: "tokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMetadata";
            isMut: false;
            isSigner: false;
        }, {
            name: "name";
            isMut: false;
            isSigner: false;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "InitializeSocialTokenV0Args";
            };
        }];
    } | {
        name: "claimSocialTokenV0";
        accounts: [{
            name: "payer";
            isMut: false;
            isSigner: true;
        }, {
            name: "collective";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "newTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenBonding";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenMetadata";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenBondingAuthority";
            isMut: false;
            isSigner: false;
        }, {
            name: "metadataUpdateAuthority";
            isMut: false;
            isSigner: false;
        }, {
            name: "name";
            isMut: false;
            isSigner: false;
        }, {
            name: "owner";
            isMut: true;
            isSigner: true;
        }, {
            name: "baseMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "targetMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "buyBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "buyTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "sellBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "sellTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newBuyBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newBuyTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newSellBaseRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "newSellTargetRoyalties";
            isMut: true;
            isSigner: false;
        }, {
            name: "royaltiesOwner";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenBondingProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenMetadataProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "systemProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "rent";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "ClaimSocialTokenV0Args";
            };
        }];
    } | {
        name: "updateTokenBondingV0";
        accounts: [{
            name: "collective";
            isMut: false;
            isSigner: false;
        }, {
            name: "authority";
            isMut: false;
            isSigner: false;
        }, {
            name: "reverseTokenRef";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenBonding";
            isMut: true;
            isSigner: false;
        }, {
            name: "tokenBondingAuthority";
            isMut: false;
            isSigner: false;
        }, {
            name: "owner";
            isMut: false;
            isSigner: true;
        }, {
            name: "tokenBondingProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "baseMint";
            isMut: false;
            isSigner: false;
        }, {
            name: "targetMint";
            isMut: false; /**
             * Run {@link claimSocialTokenInstructions}
             * @param args
             */
            isSigner: false;
        }, {
            name: "buyBaseRoyalties";
            isMut: false;
            isSigner: false;
        }, {
            name: "buyTargetRoyalties";
            isMut: false;
            isSigner: false;
        }, {
            name: "sellBaseRoyalties";
            isMut: false;
            isSigner: false;
        }, {
            name: "sellTargetRoyalties";
            isMut: false;
            isSigner: false;
        }];
        args: [{
            name: "args";
            type: {
                defined: "UpdateTokenBondingV0ArgsWrapper";
            };
        }];
    }>;
    get wallet(): import("@project-serum/anchor/dist/cjs/provider").Wallet;
    get account(): anchor.AccountNamespace<SplTokenCollectiveIDL>;
    get errors(): Map<number, string>;
    /**
     * Account decoder to a unified TokenRef interface
     *
     * @param pubkey
     * @param account
     * @returns
     */
    tokenRefDecoder: TypedAccountParser<ITokenRef>;
    /**
     * Account decoder to a unified Collective interface
     *
     * @param pubkey
     * @param account
     * @returns
     */
    collectiveDecoder: TypedAccountParser<ICollective>;
    sendInstructions(instructions: TransactionInstruction[], signers: Signer[], payer?: PublicKey): Promise<string>;
    /**
     * Instructions to create a Collective
     *
     * @param param0
     * @returns
     */
    createCollectiveInstructions({ payer, mint, authority, mintAuthority, config, bonding, metadata, }: ICreateCollectiveArgs): Promise<BigInstructionResult<{
        collective: PublicKey;
        tokenBonding?: PublicKey;
    }>>;
    /**
     * Run {@link createCollectiveInstructions}
     * @param args
     * @returns
     */
    createCollective(args: ICreateCollectiveArgs): Promise<{
        collective: PublicKey;
        tokenBonding?: PublicKey;
    }>;
    /**
     * Instructions to claim a social token
     *
     * @param param0
     * @returns
     */
    claimSocialTokenInstructions({ payer, owner, tokenRef, tokenName, symbol, buyBaseRoyalties, buyTargetRoyalties, sellBaseRoyalties, sellTargetRoyalties, ignoreMissingName, isPrimary, }: IClaimSocialTokenArgs): Promise<InstructionResult<null>>;
    /**
     * Run {@link claimSocialTokenInstructions}
     * @param args
     */
    claimSocialToken(args: IClaimSocialTokenArgs): Promise<void>;
    /**
     * Get the seeds for the PDA of a token ref given the various parameters.
     *
     * @param param0
     * @returns
     */
    static tokenRefSeeds({ owner, name, collective, isPrimary, }: ITokenRefKeyArgs): Buffer[];
    static tokenRefKey(args: ITokenRefKeyArgs, programId?: PublicKey): Promise<[PublicKey, number]>;
    static reverseTokenRefKey(mint: PublicKey, programId?: PublicKey): Promise<[PublicKey, number]>;
    /**
     * Instructions to create everything around a social token... metadata, bonding curves, etc.
     *
     * @param param0
     * @returns
     */
    createSocialTokenInstructions({ ignoreIfExists, payer, collective, name, owner, targetMintKeypair, metadata, nameClass, nameParent, tokenBondingParams, isPrimary, }: ICreateSocialTokenArgs): Promise<BigInstructionResult<{
        tokenRef: PublicKey;
        reverseTokenRef: PublicKey;
        tokenBonding: PublicKey;
    }>>;
    /**
     * Run {@link createSocialTokenInstructions}
     * @param args
     * @returns
     */
    createSocialToken(args: ICreateSocialTokenArgs): Promise<{
        tokenRef: PublicKey;
        reverseTokenRef: PublicKey;
        tokenBonding: PublicKey;
    }>;
    getUserTokensWithMeta(tokenAccounts?: TokenAccount[]): Promise<ITokenWithMetaAndAccount[]>;
}
//# sourceMappingURL=index.d.ts.map